@@ -20,7 +20,7 @@ Readonly::Array our @EXPORT_OK => qw(first_male first_female middle_female
 our $TYPE = 'two';
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # First and middle male names.
 our @first_male = our @middle_male = qw(
@@ -66,7 +66,7 @@ Jamie
 Jason
 Jay
 Joe
-JOHN
+John
 Jonathan
 Jordan
 Joseph
@@ -204,7 +204,7 @@ Mollie
 Molly
 Naomi
 Natalie
-NATASHA
+Natasha
 Niamh
 Nicola
 Nicole
@@ -3068,6 +3068,6 @@ BSD license.
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
